<?php

/**
 * @file
 * SimplerAds Updates.
 */

/**
 *  Add new fields to store Text and Flash ads.
 *  Make Image Ad field to not required.
 */
function simplerads_update_7001(&$sandbox) {

  $t = get_t();

  $instance = [
    'field_name' => 'field_ad_image',
    'entity_type' => 'node',
    'label' => $t('Ad Image'),
    'bundle' => 'simplerads',
    'description' => $t('Upload an image for this Ad.'),
    'required' => FALSE,

    'settings' => [
      'file_directory' => 'field/image',
      'file_extensions' => 'png gif jpg jpeg',
      'max_filesize' => '',
      'max_resolution' => '',
      'min_resolution' => '',
      'alt_field' => TRUE,
      'title_field' => '',
    ],

    'widget' => [
      'type' => 'image_image',
      'settings' => [
        'progress_indicator' => 'throbber',
        'preview_image_style' => 'thumbnail',
      ],
      'weight' => -2,
    ],

    'display' => [
      'default' => [
        'label' => 'hidden',
        'type' => 'image',
        'settings' => ['image_style' => 'large', 'image_link' => ''],
        'weight' => -1,
      ],
      'teaser' => [
        'label' => 'hidden',
        'type' => 'image',
        'settings' => ['image_style' => 'medium', 'image_link' => 'content'],
        'weight' => -1,
      ],
    ],
  ];
  field_update_instance($instance);

  $instance = [
    'field_name' => 'field_ad_category',
    'entity_type' => 'node',
    'label' => $t('Ad Group'),
    'bundle' => 'simplerads',
    'required' => TRUE,
    'widget' => [
      'type' => 'options_select',
      'weight' => -4,
    ],
    'display' => [
      'default' => ['type' => 'hidden'],
      'teaser' => ['type' => 'hidden'],
    ],
  ];
  field_update_instance($instance);

  $fields = [
    [
      'field_name' => 'field_ad_text',
      'type' => 'text',
      'cardinality' => 1,
      'translatable' => TRUE,
      'locked' => FALSE,
      'settings' => [],
      'storage' => [
        'type' => 'field_sql_storage',
        'settings' => [],
      ],
    ],
  ];
  foreach ($fields as $field) {
    field_create_field($field);
  }

  $instance = [
    'field_name' => 'field_ad_text',
    'entity_type' => 'node',
    'label' => $t('Text Ad'),
    'bundle' => 'simplerads',
    'description' => $t('Enter your text ad. If you would like to embed media, please configure WYSIWYG editor and input format settings.'),
    'required' => FALSE,

    'settings' => [
      'rows' => 5,
      'text_processing' => 1,
    ],

    'widget' => [
      'type' => 'text_textarea',
      'settings' => [
      ],
      'weight' => 1,
      'module' => 'text',
    ],

    'display' => [
      'default' => [
        'label' => 'hidden',
        'type' => 'text_default',
        'weight' => -1,
        'module' => 'text',
      ],
      'teaser' => [
        'label' => 'hidden',
        'type' => 'text_default',
        'weight' => -1,
      ],
    ],
  ];
  field_create_instance($instance);

  $fields = [
    [
      'field_name' => 'field_ad_type',
      'type' => 'list_text',
      'cardinality' => 1,
      'translatable' => TRUE,
      'locked' => FALSE,
      'module' => 'list',
      'settings' => [
        'allowed_values' => [
          'graphic' => $t('Image Ad'),
          'text' => $t('Text Ad'),
        ],
        'allowed_values_function' => '',
      ],
      'storage' => [
        'type' => 'field_sql_storage',
        'settings' => [],
      ],
    ],
  ];
  foreach ($fields as $field) {
    field_create_field($field);
  }

  $instance = [
    'field_name' => 'field_ad_type',
    'entity_type' => 'node',
    'label' => $t('Ad Type'),
    'bundle' => 'simplerads',
    'description' => $t('Please select Ad type.'),
    'required' => TRUE,
    'default_value' => [
      0 => [
        'value' => 'graphic',
      ],
    ],
    'settings' => [
      'allowed_values' => [
        'graphic' => $t('Image Ad'),
        'text' => $t('Text Ad'),
      ],
      'user_register_form' => FALSE,
    ],
    'user_register_form' => FALSE,
    'widget' => [
      'active' => 1,
      'type' => 'options_select',
      'weight' => -3,
      'module' => 'list',
    ],

    'display' => [
      'default' => [
        'label' => 'hidden',
        'type' => 'list_default',
        'module' => 'list',
        'weight' => -1,
      ],
      'teaser' => [
        'label' => 'hidden',
        'type' => 'list_default',
        'module' => 'list',
        'weight' => -1,
      ],
    ],
  ];
  field_create_instance($instance);
}

/**
 * Rearrange SimleAds fields.
 */
function simplerads_update_7002(&$sandbox) {

  $t = get_t();

  user_role_grant_permissions(DRUPAL_ANONYMOUS_RID, [
    'count ad impressions',
    'count ad clicks',
  ]);

  $instance = [
    'field_name' => 'field_ad_url',
    'entity_type' => 'node',
    'bundle' => 'simplerads',
    'label' => $t('URL Address'),
    'required' => FALSE,
    'widget' => [
      'type' => 'text_textfield',
      'settings' => [
        'size' => 60,
      ],
      'weight' => 1,
    ],
    'settings' => [
      'text_processing' => 0,
    ],
    'display' => [
      'default' => [
        'label' => 'above',
        'type' => 'text_default',
        'settings' => [],
      ],
    ],
  ];
  field_update_instance($instance);
}

/**
 * Modify block settings field.
 */
function simplerads_update_7003(&$sandbox) {

  $t = get_t();

  db_change_field('simplerads_blocks', 'settings', 'settings', [
    'type' => 'text',
    'not null' => TRUE,
    'description' => 'Serialized data (settings)',
  ]);

  $instance = [
    'field_name' => 'field_ad_text',
    'entity_type' => 'node',
    'label' => $t('Text Ad'),
    'bundle' => 'simplerads',
    'description' => $t('Enter your text ad. If you would like to embed media, please configure WYSIWYG editor and input format settings.'),
    'required' => FALSE,
    'settings' => [
      'rows' => 5,
      'text_processing' => 1,
    ],
    'widget' => [
      'type' => 'text_textarea',
      'settings' => [
      ],
      'weight' => 0,
      'module' => 'text',
    ],

    'display' => [
      'default' => [
        'label' => 'hidden',
        'type' => 'text_default',
        'weight' => -1,
        'module' => 'text',
      ],
      'teaser' => [
        'label' => 'hidden',
        'type' => 'text_default',
        'weight' => -1,
      ],
    ],
  ];
  field_update_instance($instance);

  $instance = [
    'field_name' => 'field_ad_url',
    'entity_type' => 'node',
    'bundle' => 'simplerads',
    'label' => $t('URL Address'),
    'required' => FALSE,
    'widget' => [
      'type' => 'text_textfield',
      'settings' => [
        'size' => 60,
      ],
      'weight' => 1,
    ],
    'settings' => [
      'text_processing' => 0,
    ],
    'display' => [
      'default' => [
        'label' => 'above',
        'type' => 'text_default',
        'settings' => [],
      ],
    ],
  ];
  field_update_instance($instance);
}

/**
 * Create a new field for URL window targeting.
 */
function simplerads_update_7004(&$sandbox) {

  $t = get_t();

  $fields = [
    [
      'field_name' => 'field_ad_url_taget',
      'type' => 'list_boolean',
      'cardinality' => 1,
      'translatable' => TRUE,
      'settings' => [
        'allowed_values' => [
          0 => $t('Open destination URL in the same window'),
          1 => $t('Open destination URL in a new window'),
        ],
        'allowed_values_function' => '',
      ],
      'module' => 'list',
      'translatable' => TRUE,
      'entity_types' => [],
    ],
  ];
  foreach ($fields as $field) {
    field_create_field($field);
  }

  $instance = [
    'field_name' => 'field_ad_url_taget',
    'entity_type' => 'node',
    'bundle' => 'simplerads',
    'label' => $t('Link Target'),
    'required' => FALSE,
    'widget' => [
      'type' => 'options_onoff',
      'settings' => [
        'display_label' => 0,
      ],
      'weight' => 2,
      'module' => 'options',
    ],
    'default_value' => [
      0 => [
        'value' => 1,
      ],
    ],
    'settings' => [
      'user_register_form' => FALSE,
    ],
    'display' => [
      'default' => [
        'label' => 'above',
        'type' => 'list_default',
        'module' => 'list',
        'settings' => [],
      ],
      'teaser' => [
        'label' => 'above',
        'settings' => [],
        'type' => 'hidden',
        'weight' => 0,
      ],
    ],
  ];
  field_create_instance($instance);

  $instance = [
    'field_name' => 'field_ad_start_date',
    'entity_type' => 'node',
    'bundle' => 'simplerads',
    'label' => $t('Active Date'),
    'description' => $t('Allowed date formats: now, tomorrow, next week, 10 September 2011, +1 day, +1 week, +1 year, +1 week 2 days 4 hours 2 seconds, next Monday, last Friday, mm/dd/yyyy hh:mm am/pm'),
    'required' => FALSE,
    'widget' => [
      'type' => 'text_textfield',
      'settings' => [
        'size' => 60,
      ],
      'weight' => 3,
    ],
    'settings' => [
      'text_processing' => 0,
    ],
    'display' => [
      'default' => [
        'label' => 'above',
        'type' => 'text_default',
        'settings' => [],
      ],
    ],
  ];
  field_update_instance($instance);

  $instance = [
    'field_name' => 'field_ad_end_date',
    'entity_type' => 'node',
    'bundle' => 'simplerads',
    'label' => $t('End Date'),
    'description' => $t('Allowed date formats: now, tomorrow, next week, 10 September 2011, +1 day, +1 week, +1 year, +1 week 2 days 4 hours 2 seconds, next Monday, last Friday, mm/dd/yyyy hh:mm am/pm'),
    'required' => FALSE,
    'widget' => [
      'type' => 'text_textfield',
      'settings' => [
        'size' => 60,
      ],
      'weight' => 4,
    ],
    'settings' => [
      'text_processing' => 0,
    ],
    'display' => [
      'default' => [
        'label' => 'above',
        'type' => 'text_default',
        'settings' => [],
      ],
    ],
  ];
  field_update_instance($instance);
}

/**
 * Create a new field for Ad status. Disable comments in SimplerAds content type.
 */
function simplerads_update_7005(&$sandbox) {

  $t = get_t();

  $fields = [
    [
      'field_name' => 'field_ad_status',
      'type' => 'list_boolean',
      'cardinality' => 1,
      'translatable' => TRUE,
      'settings' => [
        'allowed_values' => [
          0 => $t('This ad is inactive'),
          1 => $t('This ad is active'),
        ],
        'allowed_values_function' => '',
      ],
      'module' => 'list',
      'translatable' => TRUE,
      'entity_types' => [],
    ],
  ];
  foreach ($fields as $field) {
    field_create_field($field);
  }

  $instance = [
    'field_name' => 'field_ad_status',
    'entity_type' => 'node',
    'bundle' => 'simplerads',
    'label' => $t('Status'),
    'description' => $t('Please use this field to show or hide ads even if the ad is active and published.'),
    'required' => FALSE,
    'widget' => [
      'type' => 'options_onoff',
      'settings' => [
        'display_label' => 0,
      ],
      'weight' => 5,
      'module' => 'options',
    ],
    'default_value' => [
      0 => [
        'value' => 1,
      ],
    ],
    'settings' => [
      'user_register_form' => FALSE,
    ],
    'display' => [
      'default' => [
        'label' => 'above',
        'type' => 'list_default',
        'module' => 'list',
        'settings' => [],
      ],
      'teaser' => [
        'label' => 'above',
        'settings' => [],
        'type' => 'hidden',
        'weight' => 0,
      ],
    ],
  ];
  field_create_instance($instance);

  // Set all published ads to be active.
  $result = db_select('node', 'n')
    ->fields('n', ['nid'])
    ->condition('n.status', 1)
    ->condition('n.type', 'simplerads')
    ->execute();
  foreach ($result as $row) {
    $node = node_load($row->nid);
    $node->field_ad_status[$node->language][0]['value'] = 1;
    node_save($node);
  }

  // Reset menu, comments and other default options.
  variable_set('menu_options_simplerads', []);
  variable_set('node_options_simplerads', []);
  variable_set('comment_simplerads', 1);
}

/**
 * Create SimplerAds aggregated stats table.
 */
function simplerads_update_7006(&$sandbox) {

  $schema['simplerads_stats'] = [
    'description' => 'Advertisement aggregated stats',
    'fields' => [
      'nid' => [
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Advertisement node ID',
      ],
      'date' => [
        'type' => 'varchar',
        'length' => 10,
        'not null' => TRUE,
        'default' => '',
        'description' => 'Stats day',
      ],
      'clicks' => [
        'type' => 'int',
        'not null' => FALSE,
        'description' => 'Clicks counter',
      ],
      'clicks_unique' => [
        'type' => 'int',
        'not null' => FALSE,
        'description' => 'Clicks counter',
      ],
      'impressions' => [
        'type' => 'int',
        'not null' => FALSE,
        'description' => 'Impressions counter',
      ],
      'impressions_unique' => [
        'type' => 'int',
        'not null' => FALSE,
        'description' => 'Impressions counter',
      ],
    ],
    'primary key' => ['nid', 'date'],
  ];

  db_create_table('simplerads_stats', $schema['simplerads_stats']);

}
